#
# spec file for package smc-tools
#
# Copyright (c) 2018, 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# aarch64 and ppc64le don't support 32bit applications, so there's no
# gcc-32bit package that can be installed
%ifarch s390x x86_64
%define have_32bit 1
BuildRequires:  gcc-32bit
%endif

# While repos other than Factory have 32bit for s390x, Factory does not
%if 0%{?suse_version} == 1550
%ifarch s390x
%define have_32bit 0
%endif
%endif

Name:           smc-tools
Version:        1.2.1
Release:        lp151.2.3.1
Summary:        Shared Memory Communication via RDMA
License:        EPL-1.0
Group:          System/Kernel
URL:            https://www.ibm.com/developerworks/linux/linux390/smc-tools.html
Source:         %{name}-%{version}.tar.gz
Source1:        smc-tools-rpmlintrc

BuildRequires:  libnl3-devel
PreReq:         permissions

%description
Shared Memory Communication via RDMA (SMC) is a socket over RDMA
communication protocol that allows existing TCP socket applications to
transparently benefit from RDMA when exchanging data via an RDMA over
Converged Ethernet (RoCE) network.

The tools provided in this package allow existing TCP applications
to use a RoCE network without needing to make changes in them.

%prep
%setup -q

%build
MYCFLAGS=$(grep ^CFLAGS Makefile | cut -f2 -d=)
make %{?_smp_mflags} V=1 CFLAGS="${MYCFLAGS} %{optflags}"

%install
%make_install V=1

%ifarch s390 %{ix86}
rm -Rf "%{buildroot}%{_prefix}/lib64"
%endif

%verifyscript
%verify_permissions -e %{_prefix}/lib/libsmc-preload.so
%verify_permissions -e %{_libdir}/libsmc-preload.so

%post
%set_permissions %{_prefix}/lib/libsmc-preload.so
%set_permissions %{_libdir}/libsmc-preload.so

%files
%license LICENSE
%doc README.smctools
%{_bindir}/smc_dbg
%{_bindir}/smc_pnet
%{_bindir}/smc_run
%ifarch s390 s390x
%{_bindir}/smc_rnics
%endif
%{_bindir}/smcss
%{_libdir}/libsmc-preload.so
%if 0%{?have_32bit}
%{_prefix}/lib/libsmc-preload.so
%endif
%{_mandir}/man7/af_smc.7%{?ext_man}
%{_mandir}/man8/smc_pnet.8%{?ext_man}
%ifarch s390 s390x
%{_mandir}/man8/smc_rnics.8%{?ext_man}
%endif
%{_mandir}/man8/smc_run.8%{?ext_man}
%{_mandir}/man8/smcss.8%{?ext_man}

%changelog
* Tue Sep  3 2019 Mark Post <mpost@suse.com>
- Upgraded to version 1.2.1 (Fate#327839, bsc#1153947)
  * Version 1.2.1
    Bug fixes:
    smc_rnics: Install man page on s390 only
    smc-preload: Handle behavior flags in type argument to socket() call
    Makefile: Fixed install target on Ubuntu for platforms other than s390
    smc_pnet: changes in support of kernel 5.1
  * Version 1.2.0
    Changes:
    smc_rnics: Initial version added
    smc_dbg: Initial version added
    Bug fixes:
    smcss: Parse address family of ip address
* Fri Nov 30 2018 mpost@suse.com
- Made multiple changes to the spec file based on the output
  from spec-cleaner.
* Fri Jul 27 2018 mpost@suse.com
- Upgraded to version 1.1.0 (Fates 325009, 325168 and 325702)
  Changes:
  * smcss:    Add IPv6 support
  * preload:  Add IPv6 support
  * smcss:    Output format changed
  * preload:  Rename preload library into libsmc-preload.so
  * Makefile: Improve distro compatibility
  * Makefile: Add SONAME to shared libraries
  * Makefile: Do not strip binaries on install
  * Makefile: Use LDFLAGS to allow addition of externally set link flags
  * libsmc..: Remove hardcoded reference to libc
  * Manpages: Formatting changes
  Bug fixes:
  * Makefile: Fix target 'install' dependencies
  * smcss:    Fix "--version" output
  * smc_pnet: Fix "--version" output
  * smc_run:	Append preload library to LD_PRELOAD instead of potentially
    overwriting pre-set values
  * preload:  Set suid flag to work with suid executables
- Updated the spec file to reference the new names for the shared
  library.
- Removed the ExcludeArch for %%{arm} since it now builds on that
  architecture.
* Fri Sep 29 2017 mpost@suse.com
- Added an ExcludeArch for %%{arm} so that we won't try to build
  the package on armv7l. The build fails on that architecture.
* Mon Apr  3 2017 jengelh@inai.de
- Update summary. Replace old RPM shell variables by macros.
* Mon Mar 20 2017 mpost@suse.com
- Upgraded to version 1.0.0 (Fate#322376).
* Fri May  6 2016 mpost@suse.com
- Initial packaging of version 0.1.1 (Fate#319569).
